@@ -20,13 +20,13 @@ class HeartBeat:
             async def heart_beat(self) -> None:
 
                 while True:
+
                     if time.time() >= self.next_run:
 
                         await self.beat()
 
-                        self.reset_rythm()
-                        
-                    await asyncio.sleep(1)
+                    else:
+                        await asyncio.sleep(1)
 
             asyncio.run_coroutine_threadsafe(heart_beat(self), loop)
 
@@ -34,6 +34,8 @@ class HeartBeat:
         thread.daemon = True
         thread.start()
 
+        self.running = True
+
     async def beat(self) -> None:
 
         if self.rust_api.remote.ws is not None:
